# ZI DCT0

This is a Python implementation for the ZI DCT0 trading algorithm. The explanation of the algorithm is beyond the scope of this documentation.
Use at your own risk.

**Source code** [https://github.com/kiennt23/zi_dct0](url)

## Install
Use pip to install the library
```commandline
pip install zi_dct0
```

## Usage
Usage can be find in `test` page